@@ -1,6 +1,6 @@
 package Mail::TLSRPT::Pragmas;
 # ABSTRACT: Setup system wide pragmas
-our $VERSION = '1.20200305.1'; # VERSION
+our $VERSION = '1.20200306.1'; # VERSION
 use 5.20.0;
 use strict;
 use warnings;
@@ -28,3 +28,29 @@ sub import {
 
 1;
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::TLSRPT::Pragmas - Setup system wide pragmas
+
+=head1 VERSION
+
+version 1.20200306.1
+
+=head1 AUTHOR
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Marc Bradshaw.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
